@@ -565,7 +565,7 @@ public:
         return MOS_STATUS_SUCCESS;
     };
 
-    virtual MOS_STATUS SendStateComputeMpde(
+    virtual MOS_STATUS SendStateComputeMode(
         PRENDERHAL_INTERFACE pRenderHal,
         PMOS_COMMAND_BUFFER  pCmdBuffer)
     {
@@ -706,6 +706,8 @@ public:
 
     virtual std::shared_ptr<mhw::mi::Itf> GetMhwMiItf() = 0;
 
+    virtual uint32_t GetGrfSize() = 0;
+
 };
 
 #endif // __RENDERHAL_PLATFORM_INTERFACE_H__
