@@ -193,7 +193,6 @@ MOS_STATUS CodechalDecodeAvcG11::DecodeStateLevel()
 MOS_STATUS CodechalDecodeAvcG11::DecodePrimitiveLevel()
 {
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
-    CODECHAL_DECODE_PROCESSING_PARAMS *decProcessingParams = nullptr;
 
     CODECHAL_DECODE_FUNCTION_ENTER;
 
@@ -231,16 +230,16 @@ MOS_STATUS CodechalDecodeAvcG11::DecodePrimitiveLevel()
     }
 
 #ifdef _DECODE_PROCESSING_SUPPORTED
-    decProcessingParams = (CODECHAL_DECODE_PROCESSING_PARAMS *)m_decodeParams.m_procParams;
-    if (decProcessingParams != nullptr && decProcessingParams->bIsReferenceOnlyPattern)
+    DecodeProcessingParams *decProcessingParams = (DecodeProcessingParams *)m_decodeParams.m_procParams;
+    if (decProcessingParams != nullptr && decProcessingParams->m_isReferenceOnlyPattern)
     {
-        HucCopy(&cmdBuffer, 
-            &m_destSurface.OsResource, 
-            &decProcessingParams->pOutputSurface->OsResource, 
-            decProcessingParams->pOutputSurface->dwSize,
-            m_destSurface.dwOffset,
-            decProcessingParams->pOutputSurface->dwOffset
-        );
+        CODECHAL_DECODE_CHK_STATUS_RETURN(HucCopy(&cmdBuffer, 
+                                            &m_destSurface.OsResource, 
+                                            &decProcessingParams->m_outputSurface->OsResource, 
+                                            decProcessingParams->m_outputSurface->dwSize,
+                                            m_destSurface.dwOffset,
+                                            decProcessingParams->m_outputSurface->dwOffset
+        ));
     }
 #endif
 
@@ -330,6 +329,7 @@ MOS_STATUS CodechalDecodeAvcG11::DecodePrimitiveLevel()
         CodecHalDecodeSinglePipeVE_PopulateHintParams(m_veState, &cmdBuffer, true);
     }
 
+    HalOcaInterface::DumpCodechalParam(cmdBuffer, (MOS_CONTEXT_HANDLE)m_osInterface->pOsContext, m_pCodechalOcaDumper, CODECHAL_AVC);
     HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface);
 
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSubmitCommandBuffer(m_osInterface, &cmdBuffer, m_videoContextUsesNullHw));
@@ -337,7 +337,7 @@ MOS_STATUS CodechalDecodeAvcG11::DecodePrimitiveLevel()
     CODECHAL_DEBUG_TOOL(
         m_mmc->UpdateUserFeatureKey(&m_destSurface);)
 #ifdef _DECODE_PROCESSING_SUPPORTED
-    decProcessingParams = (CODECHAL_DECODE_PROCESSING_PARAMS *)m_decodeParams.m_procParams;
+    decProcessingParams = (DecodeProcessingParams *)m_decodeParams.m_procParams;
     if (decProcessingParams != nullptr && !m_sfcState->m_sfcPipeOut && (m_isSecondField || m_avcPicParams->seq_fields.mb_adaptive_frame_field_flag))
     {
         CODECHAL_DECODE_CHK_STATUS_RETURN(m_fieldScalingInterface->DoFieldScaling(
@@ -372,7 +372,7 @@ MOS_STATUS CodechalDecodeAvcG11::DecodePrimitiveLevel()
         {
             syncParams = g_cInitSyncParams;
             syncParams.GpuContext = m_renderContext;
-            syncParams.presSyncResource = &decProcessingParams->pOutputSurface->OsResource;
+            syncParams.presSyncResource = &decProcessingParams->m_outputSurface->OsResource;
 
             CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnResourceSignal(m_osInterface, &syncParams));
         }
@@ -382,12 +382,12 @@ MOS_STATUS CodechalDecodeAvcG11::DecodePrimitiveLevel()
 #ifdef _DECODE_PROCESSING_SUPPORTED
     CODECHAL_DEBUG_TOOL(
         // Dump out downsampling result
-        if (decProcessingParams && decProcessingParams->pOutputSurface)
+        if (decProcessingParams && decProcessingParams->m_outputSurface)
         {
             MOS_SURFACE dstSurface;
             MOS_ZeroMemory(&dstSurface, sizeof(dstSurface));
             dstSurface.Format = Format_NV12;
-            dstSurface.OsResource = decProcessingParams->pOutputSurface->OsResource;
+            dstSurface.OsResource = decProcessingParams->m_outputSurface->OsResource;
 
             CODECHAL_DECODE_CHK_STATUS_RETURN(CodecHalGetResourceInfo(
                 m_osInterface,
@@ -413,6 +413,6 @@ CodechalDecodeAvcG11::CodechalDecodeAvcG11(
 
     CODECHAL_DECODE_CHK_NULL_NO_STATUS_RETURN(m_osInterface);
 
-    Mos_CheckVirtualEngineSupported(m_osInterface, true, true);
+    m_osInterface->pfnVirtualEngineSupported(m_osInterface, true, true);
 };
 
