@@ -1047,7 +1047,7 @@ public:
 
     MOS_STATUS SubmitCommandBuffer(
         PMOS_COMMAND_BUFFER cmdBuffer,
-        bool nullRendering) override;
+        bool bNullRendering) override;
 
     MOS_STATUS SetMeCurbeParams(
         MeCurbeParams* meParams);
