@@ -30,9 +30,9 @@
 #include "mhw_mi_hwcmd_g12_X.h"
 #include "mhw_render_hwcmd_g12_X.h"
 #include "mhw_vdbox_avp_interface.h"
-#ifdef IGFX_MHW_INTERFACES_NEXT_SUPPORT
+#include "media_sfc_interface_legacy.h"
+
 #include "media_interfaces_mhw_next.h"
-#endif
 
 //!
 //! \enum MediaStatesAv1FilmGrain
@@ -66,17 +66,6 @@ public:
         MhwInterfaces     *mhwInterfaces,
         bool              disableScalability = false);
 
-#ifdef IGFX_MHW_INTERFACES_NEXT_SUPPORT
-    //!
-    //! \brief    Constructor
-    //!
-    CodechalHwInterfaceG12(
-        PMOS_INTERFACE    osInterface,
-        CODECHAL_FUNCTION codecFunction,
-        MhwInterfacesNext *mhwInterfacesNext,
-        bool              disableScalability = false);
-#endif
-
     //!
     //! \brief    Copy constructor
     //!
@@ -204,7 +193,6 @@ public:
     MOS_STATUS Initialize(
         CodechalSetting *settings) override;
 
-#ifdef IGFX_MHW_INTERFACES_NEXT_SUPPORT
     //!
     //! \brief    Read AVP status for status report
     //! \param    vdboxIndex
@@ -236,7 +224,7 @@ public:
         MHW_VDBOX_NODE_IND           vdboxIndex,
         const EncodeStatusReadParams &params,
         PMOS_COMMAND_BUFFER          cmdBuffer);
-#endif
+
 
     //!
     //! \brief    Get film grain kernel info
