@@ -258,7 +258,7 @@ protected:
 #if (_DEBUG || _RELEASE_INTERNAL)
 #define DO_FIELDS()                                                                             \
     DO_FIELD(DW1, FrameTileId, params.tileId);                                                  \
-    DO_FIELD(DW1, TgTileNum, params.tileNum);                                                   \
+    DO_FIELD(DW1, TgTileNum, params.tgTileNum);                                                   \
     DO_FIELD(DW1, TileGroupId, params.tileGroupId);                                             \
                                                                                                 \
     DO_FIELD(DW2, TileColumnPositionInSbUnit, params.tileColPositionInSb);                      \
@@ -285,7 +285,7 @@ protected:
 #else
 #define DO_FIELDS()                                                                             \
     DO_FIELD(DW1, FrameTileId, params.tileId);                                                  \
-    DO_FIELD(DW1, TgTileNum, params.tileNum);                                                   \
+    DO_FIELD(DW1, TgTileNum, params.tgTileNum);                                                   \
     DO_FIELD(DW1, TileGroupId, params.tileGroupId);                                             \
                                                                                                 \
     DO_FIELD(DW2, TileColumnPositionInSbUnit, params.tileColPositionInSb);                      \
