@@ -67,6 +67,9 @@ namespace CodechalDbgAttr        = MediaDbgAttr;
 #define CODECHAL_DEBUG_ASSERTMESSAGE(_message, ...) \
     MOS_ASSERTMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_DEBUG, _message, ##__VA_ARGS__)
 
+#define CODECHAL_DEBUG_WARNINGMESSAGE(_message, ...) \
+    MOS_WARNINGMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_DEBUG, _message, ##__VA_ARGS__)
+
 #define CODECHAL_DEBUG_NORMALMESSAGE(_message, ...) \
     MOS_NORMALMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_DEBUG, _message, ##__VA_ARGS__)
 
@@ -291,6 +294,14 @@ public:
         uint32_t                  offset = 0,
         CODECHAL_MEDIA_STATE_TYPE mediaState = CODECHAL_NUM_MEDIA_STATES);
 
+    virtual MOS_STATUS LoadBinaryToLockableBuffer(
+        PMOS_RESOURCE             resource,
+        const char               *attrName,
+        const char               *bufferName,
+        uint32_t                  size,
+        uint32_t                  offset     = 0,
+        CODECHAL_MEDIA_STATE_TYPE mediaState = CODECHAL_NUM_MEDIA_STATES);
+
     MOS_STATUS DumpSurface(
         PMOS_SURFACE              surface,
         const char *              attrName,
@@ -361,6 +372,18 @@ protected:
 
 private:
     MOS_STATUS VDBypassCopyResource(PMOS_RESOURCE src, PMOS_RESOURCE dst);
+    MOS_STATUS AllocateLinearResource(
+        MOS_GFXRES_TYPE eType,
+        uint32_t        dwWidth,
+        uint32_t        dwHeight,
+        MOS_FORMAT      eFormat,
+        PMOS_RESOURCE   pResource,
+        bool            bSystemMem = false,
+        bool            bLockable = false) const;
+    MOS_STATUS FillResourceMemory(
+        MOS_RESOURCE &sResource,
+        uint32_t      uiSize,
+        uint8_t       ucValue);
 
 MEDIA_CLASS_DEFINE_END(CodechalDebugInterface)
 };
