@@ -69,6 +69,7 @@ namespace decode
 
         DECODE_CHK_STATUS(UpdateCurFrame(picParams));
         DECODE_CHK_STATUS(UpdateCurRefList(picParams));
+        DECODE_CHK_STATUS(UpdateRefCachePolicy(picParams));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -353,6 +354,30 @@ namespace decode
         return MOS_STATUS_SUCCESS;
     }
 
+    MOS_STATUS AvcReferenceFrames::UpdateRefCachePolicy(const CODEC_AVC_PIC_PARAMS &picParams)
+    {
+        DECODE_FUNC_CALL();
+        MOS_STATUS sts = MOS_STATUS_SUCCESS;
+
+        AvcReferenceFrames         &refFrames     = m_basicFeature->m_refFrames;
+        const std::vector<uint8_t> &activeRefList = refFrames.GetActiveReferenceList(picParams);
+        for (uint8_t i = 0; i < activeRefList.size(); i++)
+        {
+            uint8_t frameIdx               = activeRefList[i];
+            if (frameIdx >= CODEC_AVC_NUM_UNCOMPRESSED_SURFACE)
+            {
+                continue;
+            }
+            sts = m_allocator->UpdateResoreceUsageType(&m_refList[frameIdx]->resRefPic, resourceInputReference);
+            if (sts != MOS_STATUS_SUCCESS)
+            {
+                DECODE_NORMALMESSAGE("GetReferenceByFrameIndex invalid\n");
+            }
+        }
+
+        return MOS_STATUS_SUCCESS;
+    }
+
     MOS_STATUS AvcReferenceFrames::SetFrameStoreIds(uint8_t frameIdx)
     {
         const uint8_t invalidFrame = 0x7f;
