@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2022, Intel Corporation
+* Copyright (c) 2018-2025, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -41,6 +41,9 @@
     OcaOnMosCriticalMessage(MOS_FUNCTION, __LINE__);
 #endif
 
+#define DECODE_WARNINGMESSAGE(_message, ...) \
+    MOS_WARNINGMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_DECODE, _message, ##__VA_ARGS__)
+
 #define DECODE_NORMALMESSAGE(_message, ...)                                    \
     MOS_NORMALMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_DECODE, _message, ##__VA_ARGS__)
 
@@ -97,6 +100,11 @@ public:
     {
         return m_mutex;
     }
+
+    //forbidden mutex transfer
+    Mutex(const Mutex&) = delete;
+    Mutex& operator=(const Mutex&) = delete;
+
 protected:
     PMOS_MUTEX m_mutex;
 MEDIA_CLASS_DEFINE_END(decode__Mutex)
