@@ -183,6 +183,17 @@ MOS_STATUS DecodePipeline::Initialize(void *settings)
 
     DECODE_CHK_STATUS(CreateStatusReport());
 
+#if (_DEBUG || _RELEASE_INTERNAL)
+    MOS_USER_FEATURE_VALUE_DATA userFeatureData;
+    MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
+    MOS_UserFeature_ReadValue_ID(
+        nullptr,
+        __MEDIA_USER_FEATURE_VALUE_VDBOX_CRC_OUTPUT_ENABLE_ID,
+        &userFeatureData,
+        m_osInterface->pOsContext);
+    m_crcoutputEnable = userFeatureData.i32Data ? true : false;
+#endif
+
     m_decodecp = Create_DecodeCpInterface(codecSettings, m_hwInterface->GetCpInterface(), m_hwInterface->GetOsInterface());
     if (m_decodecp)
     {
