@@ -219,8 +219,9 @@ namespace encode
         dmem->UPD_CurWidth  = (uint16_t)m_basicFeature->m_oriFrameWidth;
         dmem->UPD_CurHeight = (uint16_t)m_basicFeature->m_oriFrameHeight;
         dmem->UPD_Asyn = 0;
-        dmem->UPD_EnableAdaptiveRounding = (m_basicFeature->m_roundingMethod == RoundingMethod::adaptiveRounding);
+        dmem->UPD_EnableAdaptiveRounding = m_basicFeature->m_roundingMethod;
         dmem->UPD_AdaptiveTUEnabled = picParams->AdaptiveTUEnabled;
+        dmem->UPD_EnableDeltaQP = picParams->PicFlags.fields.EnableDeltaQP;
 
         if (seqParams->GopRefDist == 16 && m_rcMode == RATECONTROL_CQL)
             dmem->UPD_MaxBRCLevel = 4;
@@ -342,6 +343,8 @@ namespace encode
             dmem->UPD_EnableCDEFUpdate = 0;
             dmem->UPD_EnableLFUpdate   = 0;
         }
+        dmem->UPD_QMatrixEnabled = picParams->wQMatrixFlags.fields.using_qmatrix;
+        dmem->UPD_LADsRatio      = seqParams->SeqFlags.fields.LADsRatio;
 
         return MOS_STATUS_SUCCESS;
     }
@@ -605,6 +608,8 @@ namespace encode
         {
             dmem->INIT_OvershootCBR_pct = (uint16_t)(seqParams->MaxBitRatePerSlidingWindow * 100 / seqParams->TargetBitRate[0]);
         }
+        dmem->INIT_GopPicSize = seqParams->GopPicSize;
+
         return MOS_STATUS_SUCCESS;
     }
 
@@ -718,6 +723,7 @@ namespace encode
 
     MHW_SETPAR_DECL_SRC(HUC_DMEM_STATE, Av1Brc)
     {
+        ENCODE_FUNC_CALL();
         ENCODE_CHK_NULL_RETURN(params.hucDataSource);
 
         switch (params.function)
@@ -763,6 +769,7 @@ namespace encode
 
     MHW_SETPAR_DECL_SRC(HUC_VIRTUAL_ADDR_STATE, Av1Brc)
     {
+        ENCODE_FUNC_CALL();
         if (params.function == BRC_UPDATE)
         {
             const PMOS_RESOURCE brcConstDataBuffer = params.regionParams[5].presRegion;
@@ -780,6 +787,7 @@ namespace encode
 
     MHW_SETPAR_DECL_SRC(VDENC_PIPE_MODE_SELECT, Av1Brc)
     {
+        ENCODE_FUNC_CALL();
         if (m_brcEnabled)
         {
             params.frameStatisticsStreamOut = true;
