@@ -262,28 +262,6 @@ MOS_STATUS AvcVdencPipeline::ResetParams()
     auto avcBasicfeature = dynamic_cast<AvcBasicFeature *>(m_featureManager->GetFeature(FeatureIDs::basicFeature));
     ENCODE_CHK_NULL_RETURN(avcBasicfeature);
 
-#if MHW_HWCMDPARSER_ENABLED
-    char frameType = '\0';
-    switch (avcBasicfeature->m_picParam->CodingType)
-    {
-    case I_TYPE:
-        frameType = 'I';
-        break;
-    case P_TYPE:
-        frameType = 'P';
-        break;
-    case B_TYPE:
-        frameType = (avcBasicfeature->m_picParam->RefPicFlag) ? 'B' : 'b';
-        break;
-    }
-
-    auto instance = mhw::HwcmdParser::GetInstance();
-    if (instance)
-    {
-        instance->Update(frameType, (void *)m_featureManager);
-    }
-#endif
-
     m_currRecycledBufIdx = (m_currRecycledBufIdx + 1) % CODECHAL_ENCODE_RECYCLED_BUFFER_NUM;
     if (m_currRecycledBufIdx == 0)
     {
