@@ -33,6 +33,10 @@ const UFKEY_NEXT Configure::m_rootKey = UFKEY_INTERNAL_NEXT;
 const char *Configure::m_configPath = USER_SETTING_CONFIG_PATH;
 const char *Configure::m_reportPath = USER_SETTING_REPORT_PATH;
 
+#if (_DEBUG || _RELEASE_INTERNAL)
+std::set<std::string> Configure::m_nonPidRegPaths = {};
+#endif
+
 Configure::Configure(MOS_USER_FEATURE_KEY_PATH_INFO *keyPathInfo):Configure()
 {
     m_keyPathInfo = keyPathInfo;
@@ -45,6 +49,9 @@ Configure::Configure(MOS_USER_FEATURE_KEY_PATH_INFO *keyPathInfo):Configure()
     }
 
     //when statePath set, will init m_statedConfigPath and m_statedReportPath with m_keyPathInfo
+#if (_DEBUG || _RELEASE_INTERNAL)
+    m_pidPath = "\\" + std::to_string(MosUtilities::MosGetPid());
+#endif
     m_statedConfigPath = subPath + m_configPath;
     m_statedReportPath = subPath + m_reportPath;
 }
@@ -131,7 +138,7 @@ MOS_STATUS Configure::Read(Value &value,
     uint32_t option)
 {
     int32_t     ret     = 0;
-    MOS_STATUS  status  = MOS_STATUS_SUCCESS;
+    MOS_STATUS  status  = MOS_STATUS_UNKNOWN;
     auto        &defs   = GetDefinitions(group);
     auto        def     = defs[MakeHash(valueName)];
     if (def == nullptr)
@@ -145,23 +152,46 @@ MOS_STATUS Configure::Read(Value &value,
         value = useCustomValue ? customValue : def->DefaultValue();
         return MOS_STATUS_SUCCESS;
     }
-    //First, Read user setting. If succeed, return;
+    std::string path = GetReadPath(def, option);
+#if (_DEBUG || _RELEASE_INTERNAL)
+    //First, Read pid path user setting. If succeed, return;
+    if (m_nonPidRegPaths.find(path) == m_nonPidRegPaths.end())
     {
-        std::string path = GetReadPath(def, option);
+        std::string pathPidSuffix = path + m_pidPath;
+        UFKEY_NEXT  keyPidSuffix  = {};
+        m_mutexLock.Lock();
+        status = MosUtilities::MosOpenRegKey(m_rootKey, pathPidSuffix, KEY_READ, &keyPidSuffix, m_regBufferMap);
+        if (status == MOS_STATUS_SUCCESS)
+        {
+            status = MosUtilities::MosGetRegValue(keyPidSuffix, valueName, defaultType, value, m_regBufferMap);
+            MosUtilities::MosCloseRegKey(keyPidSuffix);
+        }
+        else
+        {
+            // Record the reg path which does not have inner pid reg path.
+            m_nonPidRegPaths.insert(path);
+        }
+        m_mutexLock.Unlock();
+    }
+    //Second, if reading pid path failed, read non-pid path. If succeed, return;
+    if (status != MOS_STATUS_SUCCESS)
+#endif
+    {
         UFKEY_NEXT  key  = {};
 
+        m_mutexLock.Lock();
+
         status = MosUtilities::MosOpenRegKey(m_rootKey, path, KEY_READ, &key, m_regBufferMap);
-
         if (status == MOS_STATUS_SUCCESS)
         {
-            m_mutexLock.Lock();
             status = MosUtilities::MosGetRegValue(key, valueName, defaultType, value, m_regBufferMap);
-            m_mutexLock.Unlock();
             MosUtilities::MosCloseRegKey(key);
         }
+
+        m_mutexLock.Unlock();
     }
 
-    //Second, if 1st failed, read envionment variable. External user setting does not set env varaible now.
+    //Third, if reading key failed, read envionment variable. External user setting does not set env varaible now.
     if (status != MOS_STATUS_SUCCESS && option == MEDIA_USER_SETTING_INTERNAL)
     {
         // read env variable if no user setting set
@@ -215,19 +245,45 @@ MOS_STATUS Configure::Write(
 
     std::string path = GetReportPath(def, option);
 
-    UFKEY_NEXT key = {};
     MOS_STATUS status = MOS_STATUS_UNKNOWN;
-
-    m_mutexLock.Lock();
-    status = MosUtilities::MosCreateRegKey(m_rootKey, path, KEY_WRITE, &key, m_regBufferMap);
-
-    if (status == MOS_STATUS_SUCCESS)
+#if (_DEBUG || _RELEASE_INTERNAL)
+    if (m_nonPidRegPaths.find(path) == m_nonPidRegPaths.end())
     {
-        status = MosUtilities::MosSetRegValue(key, valueName, value, m_regBufferMap);
+        std::string pathPidSuffix = path + m_pidPath;
+        UFKEY_NEXT keyPidSuffix = {};
 
-        MosUtilities::MosCloseRegKey(key);
+        m_mutexLock.Lock();
+        status = MosUtilities::MosOpenRegKey(m_rootKey, pathPidSuffix, KEY_WRITE, &keyPidSuffix, m_regBufferMap);
+
+        if (status == MOS_STATUS_SUCCESS)
+        {
+            status = MosUtilities::MosSetRegValue(keyPidSuffix, valueName, value, m_regBufferMap);
+
+            MosUtilities::MosCloseRegKey(keyPidSuffix);
+        }
+        else
+        {
+            // Record the reg path which does not have inner pid reg path.
+            m_nonPidRegPaths.insert(path);
+        }
+        m_mutexLock.Unlock();
+    }
+
+    if (status != MOS_STATUS_SUCCESS)
+#endif
+    {
+        UFKEY_NEXT key = {};
+        m_mutexLock.Lock();
+        status = MosUtilities::MosCreateRegKey(m_rootKey, path, KEY_WRITE, &key, m_regBufferMap);
+
+        if (status == MOS_STATUS_SUCCESS)
+        {
+            status = MosUtilities::MosSetRegValue(key, valueName, value, m_regBufferMap);
+
+            MosUtilities::MosCloseRegKey(key);
+        }
+        m_mutexLock.Unlock();
     }
-    m_mutexLock.Unlock();
 
     if (status != MOS_STATUS_SUCCESS)
     {
@@ -252,6 +308,10 @@ std::string Configure::GetReadPath(
     {
         return def->GetSubPath();
     }
+    else if (option == MEDIA_USER_SETTING_INTERNAL_REPORT)
+    {
+        return m_statedReportPath;
+    }
     else
     {
         return GetExternalPath(option);
