@@ -1129,13 +1129,17 @@ protected:
 MEDIA_CLASS_DEFINE_END(vp__SwFilterCgc)
 };
 
-
+#define AI_FEATURE_PARAM_EXTENSION_SIZE_MAX 32
 
 struct FeatureParamAi : public FeatureParam
 {
-    uint32_t             stageIndex      = 0;
-    AI_SETTING_PIPE      settings        = {};
-    AI_SPLIT_GROUP_INDEX splitGroupIndex = {};
+    uint32_t             stageIndex                                          = 0;
+    AI_SETTING_PIPE      settings                                            = {};
+    AI_SPLIT_GROUP_INDEX splitGroupIndex                                     = {};
+    VPHAL_PERFTAG        perfTag                                             = VPHAL_NONE;
+    FeatureType          featureType                                         = FeatureTypeInvalid;
+
+    uint8_t extensionParam[AI_FEATURE_PARAM_EXTENSION_SIZE_MAX] = {};
 };
 
 class SwFilterAiBase : public SwFilter
@@ -1154,6 +1158,7 @@ public:
     virtual MOS_STATUS       InitializeStageGroupIndex(AI_SETTING_PIPE &settingPipe, AI_SPLIT_GROUP_INDEX &splitGroupIndex);
     // This need to be implemented by derived class
     virtual MOS_STATUS RegisterAiSettingPipe(VP_PIPELINE_PARAMS &params, AI_SETTING_PIPE &settingPipe) = 0;
+    virtual MOS_STATUS SetPerfTag(VPHAL_PERFTAG &perfTag);
 
     virtual MOS_STATUS AddFeatureGraphRTLog()
     {
