@@ -198,6 +198,8 @@ MOS_STATUS VpRenderCmdPacket::Prepare()
     VP_RENDER_CHK_NULL_RETURN(m_renderHal);
     VP_RENDER_CHK_NULL_RETURN(m_kernelSet);
     VP_RENDER_CHK_NULL_RETURN(m_surfMemCacheCtl);
+    VP_RENDER_CHK_NULL_RETURN(m_hwInterface);
+    VP_RENDER_CHK_NULL_RETURN(m_hwInterface->m_vpPlatformInterface);
 
     if (m_renderHal->pStateHeap == nullptr)
     {
@@ -224,8 +226,9 @@ MOS_STATUS VpRenderCmdPacket::Prepare()
         return MOS_STATUS_SUCCESS;
     }
 
-    m_renderHal->euThreadSchedulingMode = 0;
-    m_renderHal->largeGrfMode           = 0;
+    m_renderHal->euThreadSchedulingMode                  = 0;
+    m_renderHal->largeGrfMode                            = 0;
+    m_renderHal->enableVariableRegisterSizeAllocationVrt = m_hwInterface->m_vpPlatformInterface->IsVrtEnabled();
 
     VP_RENDER_CHK_STATUS_RETURN(m_kernelSet->CreateKernelObjects(
         m_renderKernelParams,
@@ -475,7 +478,6 @@ MOS_STATUS VpRenderCmdPacket::Submit(MOS_COMMAND_BUFFER *commandBuffer, uint8_t
         return MOS_STATUS_INVALID_PARAMETER;
     }
 
-
     if (!m_surfSetting.dumpLaceSurface &&
         !m_surfSetting.dumpPostSurface)
     {
@@ -547,8 +549,12 @@ MOS_STATUS VpRenderCmdPacket::InitSurfMemCacheControl(VP_EXECUTE_CAPS packetCaps
 
     pSettings->bCompositing = packetCaps.bComposite;
     pSettings->bDnDi = true;
-    pSettings->bLace = MEDIA_IS_SKU(m_hwInterface->m_skuTable, FtrLace);
-    pSettings->bHdr  = MEDIA_IS_SKU(m_hwInterface->m_skuTable, FtrHDR);
+
+    if (m_hwInterface->m_skuTable)
+    {
+        pSettings->bLace = MEDIA_IS_SKU(m_hwInterface->m_skuTable, FtrLace);
+        pSettings->bHdr  = MEDIA_IS_SKU(m_hwInterface->m_skuTable, FtrHDR);
+    }
 
     VP_RENDER_CHK_STATUS_RETURN(InitFcMemCacheControl(pSettings));
 
@@ -781,7 +787,7 @@ MOS_STATUS VpRenderCmdPacket::SetupSurfaceState()
                 bWrite = false;
             }
 
-            std::vector<uint64_t> stateGfxAddress;
+            std::vector<RENDERHAL_STATE_LOCATION> stateLocations;
             if (kernelSurfaceParam->surfaceOverwriteParams.bindedKernel && !kernelSurfaceParam->surfaceOverwriteParams.bufferResource)
             {
                 auto bindingMap = m_kernel->GetSurfaceBindingIndex(type);
@@ -795,7 +801,7 @@ MOS_STATUS VpRenderCmdPacket::SetupSurfaceState()
                     &renderSurfaceParams,
                     bindingMap,
                     bWrite,
-                    stateGfxAddress,
+                    stateLocations,
                     kernelSurfaceParam->iCapcityOfSurfaceEntry,
                     kernelSurfaceParam->surfaceEntries,
                     kernelSurfaceParam->sizeOfSurfaceEntries));
@@ -821,7 +827,7 @@ MOS_STATUS VpRenderCmdPacket::SetupSurfaceState()
                         &renderSurfaceParams,
                         bindingMap,
                         bWrite,
-                        stateGfxAddress));
+                        stateLocations));
                     for (uint32_t const &bti : bindingMap)
                     {
                         VP_RENDER_NORMALMESSAGE("Using Binded Index Buffer. KernelID %d, SurfType %d, bti %d", m_kernel->GetKernelId(), type, bti);
@@ -839,7 +845,7 @@ MOS_STATUS VpRenderCmdPacket::SetupSurfaceState()
                         &renderHalSurface,
                         &renderSurfaceParams,
                         bWrite,
-                        stateGfxAddress);
+                        stateLocations);
                     VP_RENDER_CHK_STATUS_RETURN(m_kernel->UpdateCurbeBindingIndex(type, index));
                     VP_RENDER_NORMALMESSAGE("Using UnBinded Index Buffer. KernelID %d, SurfType %d, bti %d", m_kernel->GetKernelId(), type, index);
                 }
@@ -850,15 +856,15 @@ MOS_STATUS VpRenderCmdPacket::SetupSurfaceState()
                         &renderHalSurface,
                         &renderSurfaceParams,
                         bWrite,
-                        stateGfxAddress);
+                        stateLocations);
                     VP_RENDER_CHK_STATUS_RETURN(m_kernel->UpdateCurbeBindingIndex(type, index));
                     VP_RENDER_NORMALMESSAGE("Using UnBinded Index Surface. KernelID %d, SurfType %d, bti %d. If 1D buffer overwrite to 2D for use, it will go SetSurfaceForHwAccess()", m_kernel->GetKernelId(), type, index);
                 }
             }
 
-            if (stateGfxAddress.size() > 0)
+            if (stateLocations.size() > 0)
             {
-                m_kernel->UpdateBindlessSurfaceResource(type, stateGfxAddress);
+                m_kernel->UpdateBindlessSurfaceResource(type, stateLocations);
             }
         }
         VP_RENDER_CHK_STATUS_RETURN(m_kernel->UpdateCompParams());
@@ -977,8 +983,6 @@ MOS_STATUS VpRenderCmdPacket::SetupCurbeStateInBindlessMode()
     MT_LOG1(MT_VP_HAL_RENDER_SETUP_CURBE_STATE, MT_NORMAL, MT_FUNC_START, 1);
     VP_RENDER_CHK_NULL_RETURN(m_kernel);
     VP_PUBLIC_CHK_NULL_RETURN(m_renderHal->pStateHeap);
-    VP_PUBLIC_CHK_NULL_RETURN(m_osInterface);
-    VP_PUBLIC_CHK_NULL_RETURN(m_osInterface->pfnGetResourceGfxAddress);
     // set the Curbe Data length
     void    *curbeData          = nullptr;
     uint32_t curbeLength        = 0;
@@ -999,15 +1003,11 @@ MOS_STATUS VpRenderCmdPacket::SetupCurbeStateInBindlessMode()
         RENDER_PACKET_ASSERTMESSAGE("Curbe Set Fail, return error");
         return MOS_STATUS_UNKNOWN;
     }
-    
-    PMOS_RESOURCE resource = &m_renderHal->pStateHeap->GshOsResource;
-    VP_PUBLIC_CHK_VALUE_RETURN(Mos_ResourceIsNull(resource), false);
-    uint64_t gfxAddress = m_osInterface->pfnGetResourceGfxAddress(m_osInterface, resource) +
-                          m_renderHal->pStateHeap->pCurMediaState->dwOffset +
-                          m_renderHal->pStateHeap->dwOffsetCurbe +
-                          m_renderData.iCurbeOffset;
-    VP_PUBLIC_CHK_STATUS_RETURN(m_kernel->SetCurbeGfxAddress(gfxAddress));
-    
+
+    VP_PUBLIC_CHK_STATUS_RETURN(m_kernel->UpdateCurbeStateHeapInfo(
+        &m_renderHal->pStateHeap->GshOsResource, 
+        m_renderHal->pStateHeap->pGshBuffer, 
+        m_renderHal->pStateHeap->pCurMediaState->dwOffset + m_renderHal->pStateHeap->dwOffsetCurbe + m_renderData.iCurbeOffset));
 
     m_renderData.iCurbeLength = curbeLengthAligned;
 
@@ -1048,6 +1048,12 @@ MOS_STATUS VpRenderCmdPacket::SetupCurbeState()
  
     m_totalCurbeSize += m_renderData.iCurbeLength;
 
+    VP_RENDER_CHK_NULL_RETURN(m_renderHal->pStateHeap);
+    VP_PUBLIC_CHK_STATUS_RETURN(m_kernel->UpdateCurbeStateHeapInfo(
+        &m_renderHal->pStateHeap->GshOsResource,
+        m_renderHal->pStateHeap->pGshBuffer,
+        m_renderHal->pStateHeap->pCurMediaState->dwOffset + m_renderHal->pStateHeap->dwOffsetCurbe + m_renderData.iCurbeOffset));
+
     m_kernel->FreeCurbe(curbeData);
     MT_LOG2(MT_VP_HAL_RENDER_SETUP_CURBE_STATE, MT_NORMAL, MT_FUNC_END, 1, MT_MOS_STATUS, MOS_STATUS_SUCCESS);
 
@@ -1932,12 +1938,13 @@ void VpRenderCmdPacket::PrintWalkerParas(MHW_GPGPU_WALKER_PARAMS& WalkerParams)
         WalkerParams.GroupStartingY,
         WalkerParams.GroupStartingZ,
         WalkerParams.SLMSize);
-    VP_RENDER_VERBOSEMESSAGE("GpGPU WalkerParams: GenerateLocalId %d, EmitLocal %d, EmitInlineParameter %d, HasBarrier %d, SIMD size %d",
+    VP_RENDER_VERBOSEMESSAGE("GpGPU WalkerParams: GenerateLocalId %d, EmitLocal %d, EmitInlineParameter %d, HasBarrier %d, SIMD size %d, RegistersPerThread %d",
         WalkerParams.isGenerateLocalID,
         WalkerParams.emitLocal,
         WalkerParams.isEmitInlineParameter,
         WalkerParams.hasBarrier,
-        WalkerParams.simdSize);
+        WalkerParams.simdSize,
+        WalkerParams.registersPerThread);
     VP_RENDER_VERBOSEMESSAGE("GpGPU WalkerParams: InlineDataLength = %d, InlineData = %s",
         WalkerParams.inlineDataLength,
         inlineData.c_str());
@@ -2034,7 +2041,7 @@ MOS_STATUS VpRenderCmdPacket::SendMediaStates(
         }
         else
         {
-            pRenderHal->pRenderHalPltInterface->SendStateComputeMpde(pRenderHal, pCmdBuffer);
+            pRenderHal->pRenderHalPltInterface->SendStateComputeMode(pRenderHal, pCmdBuffer);
         }
     }
 
@@ -2224,6 +2231,7 @@ MOS_STATUS VpRenderCmdPacket::SetAiParams(PRENDER_AI_PARAMS params)
         kernelParam.kernelArgs                     = krnParams.kernelArgs;
         kernelParam.kernelThreadSpace.uWidth       = krnParams.threadWidth;
         kernelParam.kernelThreadSpace.uHeight      = krnParams.threadHeight;
+        kernelParam.kernelThreadSpace.uDepth       = krnParams.threadDepth;
         kernelParam.kernelThreadSpace.uLocalWidth  = krnParams.localWidth;
         kernelParam.kernelThreadSpace.uLocalHeight = krnParams.localHeight;
         kernelParam.syncFlag                       = true;
