@@ -27,6 +27,7 @@
 #include "vp_platform_interface.h"
 #include "vp_visa.h"
 #include "vp_user_setting.h"
+#include "vp_feature_manager_softlet.h"
 
 using namespace vp;
 extern const Kdll_RuleEntry g_KdllRuleTable_Next[];
@@ -156,6 +157,11 @@ MOS_STATUS VpRenderKernel::Destroy()
     return MOS_STATUS_SUCCESS;
 }
 
+VPFeatureManager* VpPlatformInterface::CreateFeatureChecker(_VP_MHWINTERFACE *hwInterface)
+{
+    return MOS_New(VPFeatureManagerSoftlet, hwInterface);
+}
+
 MOS_STATUS VpPlatformInterface::InitPolicyRules(VP_POLICY_RULES &rules)
 {
     VP_FUNC_CALL();
@@ -196,7 +202,7 @@ MOS_STATUS VpPlatformInterface::InitPolicyRules(VP_POLICY_RULES &rules)
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_STATUS VpRenderKernel::SetKernelName(std::string kernelname)
+MOS_STATUS VpRenderKernel::SetKernelName(const std::string &kernelname)
 {
     VP_FUNC_CALL();
     m_kernelName.assign(kernelname);
@@ -686,7 +692,7 @@ bool VpPlatformInterface::IsVeboxScalabilityWith4KNotSupported(
 void VpPlatformInterface::DisableRender()
 {
     // media sfc interface should come to here.
-    VP_PUBLIC_NORMALMESSAGE("Disable Render.");
+    VP_PUBLIC_NORMALMESSAGE("Disable Render for media sfc interface path.");
     m_isRenderDisabled = true;
 }
 
@@ -698,6 +704,14 @@ MOS_STATUS VpRenderKernel::SetKernelExeEnv(KRN_EXECUTE_ENV &exeEnv)
     return MOS_STATUS_SUCCESS;
 }
 
+//for L0 use only
+MOS_STATUS VpRenderKernel::SetKernelPerThreadArgInfo(KRN_PER_THREAD_ARG_INFO &perThreadArgInfo)
+{
+    VP_FUNC_CALL();
+    m_kernelPerThreadArgInfo = perThreadArgInfo;
+    return MOS_STATUS_SUCCESS;
+}
+
 //for L0 use only
 MOS_STATUS VpRenderKernel::AddKernelBti(KRN_BTI &bti)
 {
@@ -717,26 +731,37 @@ MOS_STATUS VpRenderKernel::SetKernelCurbeSize(uint32_t size)
 
 //for L0 use only
 void VpPlatformInterface::InitVpDelayedNativeAdvKernel(
-    const uint32_t  *kernelBin,
-    uint32_t         kernelBinSize,
-    KRN_ARG         *kernelArgs,
-    uint32_t         kernelArgSize,
-    uint32_t         kernelCurbeSize,
-    KRN_EXECUTE_ENV &kernelExeEnv,
-    KRN_BTI         *kernelBtis,
-    uint32_t         kernelBtiSize,
-    std::string      kernelName)
+    const uint32_t         *kernelBin,
+    uint32_t                kernelBinSize,
+    KRN_ARG                *kernelArgs,
+    uint32_t                kernelArgSize,
+    uint32_t                kernelCurbeSize,
+    KRN_EXECUTE_ENV        &kernelExeEnv,
+    KRN_BTI                *kernelBtis,
+    uint32_t                kernelBtiSize,
+    std::string             kernelName,
+    KRN_PER_THREAD_ARG_INFO perThreadArgInfo)
 {
     VP_FUNC_CALL();
 
     VpRenderKernel vpKernel;
 
+    bool localIdGeneratedByRuntime = (kernelExeEnv.uiSlmSize > 0 && kernelExeEnv.uSimdSize == 1);
+
     vpKernel.SetKernelBinPointer((void *)kernelBin);
     vpKernel.SetKernelName(kernelName);
-    vpKernel.SetKernelBinOffset(kernelExeEnv.uOffsetToSkipPerThreadDataLoad);
-    vpKernel.SetKernelBinSize(kernelBinSize - kernelExeEnv.uOffsetToSkipPerThreadDataLoad);
+    if (localIdGeneratedByRuntime)
+    {
+        vpKernel.SetKernelBinSize(kernelBinSize);
+    }
+    else
+    {
+        vpKernel.SetKernelBinOffset(kernelExeEnv.uOffsetToSkipPerThreadDataLoad);
+        vpKernel.SetKernelBinSize(kernelBinSize - kernelExeEnv.uOffsetToSkipPerThreadDataLoad);
+    }
     vpKernel.SetKernelExeEnv(kernelExeEnv);
     vpKernel.SetKernelCurbeSize(kernelCurbeSize);
+    vpKernel.SetKernelPerThreadArgInfo(perThreadArgInfo);
 
     for (uint32_t i = 0; i < kernelArgSize; ++i)
     {
