@@ -48,8 +48,6 @@
 
 namespace mhw { namespace mi { class Itf; } }
 
-std::map<uint32_t*, MOS_OCA_BUFFER_HANDLE> HalOcaInterfaceNext::s_hOcaMap;
-
 /****************************************************************************************************/
 /*                                      HalOcaInterfaceNextNext                                             */
 /****************************************************************************************************/
@@ -313,15 +311,58 @@ void HalOcaInterfaceNext::DumpResourceInfo(MOS_COMMAND_BUFFER &cmdBuffer, MOS_IN
         OnOcaError(&mosContext, MOS_STATUS_INVALID_PARAMETER, __FUNCTION__, __LINE__);
         return;
     }
-
-    status = pOcaInterface->AddResourceToDumpList(ocaBufHandle, &mosContext, res, hwCmdType, locationInCmd, offsetInRes);
+    if (hwCmdType == MOS_BINDLESS_STATELESS_SURFACE && (res.Format == Format_Buffer || res.Format == Format_RAW))
+    {
+        status = pOcaInterface->AddBufferResourceToDumpList(ocaBufHandle, &mosContext, res, hwCmdType, cmdBuffer.iOffset, offsetInRes);
+    }
+    else
+    {
+        status = pOcaInterface->AddResourceToDumpList(ocaBufHandle, &mosContext, res, hwCmdType, locationInCmd, offsetInRes);
+    }
     if (MOS_FAILED(status))
     {
         OnOcaError(&mosContext, status, __FUNCTION__, __LINE__);
     }
 }
 
-    //!
+//!
+//! \brief  Insert bindless/stateless resource state heap into OcaBufferHandlerMap
+//! \param  [in] key
+//!         The base address of resource state heap
+//! \param  [in] osInterface
+//!         Reference to PMOS_INTERFACE.
+//! \param  [in] cmdBuffer
+//!         Command buffer for current BB.
+//! \return void
+//!         No return value. Handle all exception inside the function.
+//!
+void HalOcaInterfaceNext::InsertResourceHeapToCurrentCmdBufferOcaBufferHandle(uint32_t *key, PMOS_INTERFACE osInterface, PMOS_COMMAND_BUFFER _cmdBuffer)
+{
+    if (nullptr == osInterface || nullptr == osInterface->pOsContext || nullptr == _cmdBuffer)
+    {
+        OnOcaError(nullptr, MOS_STATUS_INVALID_PARAMETER, __FUNCTION__, __LINE__);
+        return;
+    }
+    MOS_CONTEXT          &mosContext    = *osInterface->pOsContext;
+    MosOcaInterface      *pOcaInterface = &MosOcaInterfaceSpecific::GetInstance();
+    MOS_STATUS            status        = MOS_STATUS_SUCCESS;
+    MOS_OCA_BUFFER_HANDLE hOcaBuf       = 0;
+    MOS_COMMAND_BUFFER   &cmdBuffer     = _cmdBuffer->cmdBuf1stLvl ? *_cmdBuffer->cmdBuf1stLvl : *_cmdBuffer;
+
+    if (nullptr == pOcaInterface || (hOcaBuf = GetOcaBufferHandle(cmdBuffer, (MOS_CONTEXT_HANDLE)&mosContext)) == 0)
+    {
+        // Will come here for UMD_OCA not being enabled case.
+        return;
+    }
+
+    status = pOcaInterface->InsertOcaBufHandleMap(key, hOcaBuf);
+    if (MOS_FAILED(status))
+    {
+        OnOcaError(&mosContext, status, __FUNCTION__, __LINE__);
+    }
+}
+
+//!
 //! \brief  Trace OCA Sku Value.
 //! \param  [in] cmdBuffer
 //!         Command buffer for current BB.
@@ -346,10 +387,12 @@ void HalOcaInterfaceNext::TraceOcaSkuValue(MOS_COMMAND_BUFFER &cmdBuffer, MOS_IN
 //!         If vpKernelID == kernelCombinedFc, fcKernelCount is the kernel count for fc, otherwise, it's not used.
 //! \param  [in] fcKernelList
 //!         If vpKernelID == kernelCombinedFc, fcKernelList is the kernel list for fc, otherwise, it's not used.
+//! \param  [in] aiKernelFeatureType
+//!         Value of enum FeatureType for Ai Common Kernel.
 //! \return void
 //!         No return value. Handle all exception inside the function.
 //!
-void HalOcaInterfaceNext::DumpVpKernelInfo(MOS_COMMAND_BUFFER &cmdBuffer, MOS_CONTEXT_HANDLE mosContext, int vpKernelID, int fcKernelCount, int *fcKernelList)
+void HalOcaInterfaceNext::DumpVpKernelInfo(MOS_COMMAND_BUFFER &cmdBuffer, MOS_CONTEXT_HANDLE mosContext, int vpKernelID, int fcKernelCount, int *fcKernelList, int aiKernelFeatureType)
 {
     MosOcaInterface *pOcaInterface          = &MosOcaInterfaceSpecific::GetInstance();
     MOS_STATUS              status          = MOS_STATUS_SUCCESS;
@@ -384,7 +427,14 @@ void HalOcaInterfaceNext::DumpVpKernelInfo(MOS_COMMAND_BUFFER &cmdBuffer, MOS_CO
     header.header.headerSize                = sizeof(MOS_OCA_LOG_HEADER_VP_KERNEL_INFO);
     header.header.dataSize                  = fcKernelCount * sizeof(int);
     header.vpKernelID                       = vpKernelID;
-    header.fcKernelCount                    = fcKernelCount;
+    if (aiKernelFeatureType > 0 && vpKernelID >= kernelAiCommon && vpKernelID <= kernelAiCommonEnd)
+    {
+        header.aiKernelFeatureType = aiKernelFeatureType;
+    }
+    else
+    {
+        header.fcKernelCount = fcKernelCount;
+    }
     status = pOcaInterface->DumpDataBlock(ocaBufHandle, (PMOS_CONTEXT)mosContext, (PMOS_OCA_LOG_HEADER)&header, fcKernelList);
     if (MOS_FAILED(status))
     {
@@ -392,6 +442,41 @@ void HalOcaInterfaceNext::DumpVpKernelInfo(MOS_COMMAND_BUFFER &cmdBuffer, MOS_CO
     }
 }
 
+//!
+//! \brief  Add vp kernel info to oca log section.
+//! \param  [in] cmdBuffer
+//!         Command buffer for current BB.
+//! \param  [in] mosContext
+//!         Reference to MOS_CONTEXT.
+//! \param  [in] pControlValues
+//!         Value of user features.
+//! \return void
+//!         No return value. Handle all exception inside the function.
+//!
+void HalOcaInterfaceNext::DumpVpUserFeautreControlInfo(MOS_COMMAND_BUFFER &cmdBuffer, MOS_CONTEXT_HANDLE mosContext, PMOS_OCA_LOG_USER_FEATURE_CONTROL_INFO pControlValues)
+{
+    MosOcaInterface      *pOcaInterface = &MosOcaInterfaceSpecific::GetInstance();
+    MOS_STATUS            status        = MOS_STATUS_SUCCESS;
+    MOS_OCA_BUFFER_HANDLE hOcaBuf       = 0;
+
+    if (nullptr == pOcaInterface || (hOcaBuf = GetOcaBufferHandle(cmdBuffer, mosContext)) == MOS_OCA_INVALID_BUFFER_HANDLE)
+    {
+        // Will come here for UMD_OCA not being enabled case.
+        return;
+    }
+
+    MOS_OCA_LOG_HEADER header                           = {};
+    header.type                                         = MOS_OCA_LOG_TYPE_VP_USER_FEATURE_CONTROL_INFO;
+    header.headerSize                                   = sizeof(MOS_OCA_LOG_HEADER);
+    header.dataSize                                     = sizeof(MOS_OCA_LOG_USER_FEATURE_CONTROL_INFO);
+
+    status = pOcaInterface->DumpDataBlock(hOcaBuf, (PMOS_CONTEXT)mosContext, (PMOS_OCA_LOG_HEADER)&header, pControlValues);
+    if (MOS_FAILED(status))
+    {
+        OnOcaError(mosContext, status, __FUNCTION__, __LINE__);
+    }
+}
+
 //!
 //! \brief  Add vphal parameters to oca log section.
 //! \param  [in] mosContext
@@ -506,8 +591,12 @@ void HalOcaInterfaceNext::AddRTLogReource(MOS_COMMAND_BUFFER &cmdBuffer,
     {
         return;
     }
-    osInterface.pfnGetRtLogResourceInfo(osInterface.osStreamState, osResource, size);
-    
+    osInterface.pfnGetRtLogResourceInfo(&osInterface, osResource, size);
+    if(osResource == nullptr || size == 0)
+    {
+        return;
+    }
+
     MOS_LINUX_BO *bo = cmdBuffer.OsResource.bo;
     if (bo == nullptr ||
         bo->virt == nullptr ||
@@ -551,6 +640,10 @@ void HalOcaInterfaceNext::DumpCpParam(MosOcaInterface &ocaInterface, MOS_OCA_BUF
 {
 }
 
+void HalOcaInterfaceNext::DumpCpIoMsg(MOS_COMMAND_BUFFER &cmdBuffer, MOS_CONTEXT_HANDLE mosContext, void *pCpDumper, int type)
+{
+}
+
 void HalOcaInterfaceNext::OnOcaError(MOS_CONTEXT_HANDLE mosCtx, MOS_STATUS status, const char *functionName, uint32_t lineNumber)
 {
     MosOcaInterfaceSpecific::OnOcaError((PMOS_CONTEXT)mosCtx, status, functionName, lineNumber);
@@ -564,24 +657,8 @@ MOS_OCA_BUFFER_HANDLE HalOcaInterfaceNext::GetOcaBufferHandle(MOS_COMMAND_BUFFER
         OnOcaError(mosContext, MOS_STATUS_NULL_POINTER, __FUNCTION__, __LINE__);
         return MOS_OCA_INVALID_BUFFER_HANDLE;
     }
-    PMOS_MUTEX mutex = pOcaInterface->GetMutex();
-    if (mutex == nullptr)
-    {
-        return MOS_OCA_INVALID_BUFFER_HANDLE;
-    }
-    MosOcaAutoLock autoLock(mutex);
-    std::map<uint32_t*, MOS_OCA_BUFFER_HANDLE>::iterator it = s_hOcaMap.find(cmdBuffer.pCmdBase);
-    if (it == s_hOcaMap.end())
-    {
-        // May come here for workloads not enabling UMD_OCA.
-        return MOS_OCA_INVALID_BUFFER_HANDLE;
-    }
-    if (it->second >= MAX_NUM_OF_OCA_BUF_CONTEXT || it->second < 0)
-    {
-        OnOcaError(mosContext, MOS_STATUS_NULL_POINTER, __FUNCTION__, __LINE__);
-        return MOS_OCA_INVALID_BUFFER_HANDLE;
-    }
-    return it->second;
+
+    return pOcaInterface->GetOcaBufHandleFromMap(cmdBuffer.pCmdBase);
 }
 
 void HalOcaInterfaceNext::RemoveOcaBufferHandle(MOS_COMMAND_BUFFER &cmdBuffer, MOS_CONTEXT &mosContext)
@@ -592,19 +669,7 @@ void HalOcaInterfaceNext::RemoveOcaBufferHandle(MOS_COMMAND_BUFFER &cmdBuffer, M
         OnOcaError(&mosContext, MOS_STATUS_NULL_POINTER, __FUNCTION__, __LINE__);
         return;
     }
-    PMOS_MUTEX      mutex = pOcaInterface->GetMutex();
-    if (mutex == nullptr)
-    {
-        OnOcaError(&mosContext, MOS_STATUS_INVALID_PARAMETER, __FUNCTION__, __LINE__);
-        return;
-    }
-    MosOcaAutoLock autoLock(mutex);
-    std::map<uint32_t*, MOS_OCA_BUFFER_HANDLE>::iterator it = s_hOcaMap.find(cmdBuffer.pCmdBase);
-    if (it == s_hOcaMap.end())
-    {
-        return;
-    }
-    s_hOcaMap.erase(it);
+    pOcaInterface->RemoveOcaBufHandleFromMap(cmdBuffer.pCmdBase);
 }
 
 //!
@@ -631,12 +696,7 @@ void HalOcaInterfaceNext::On1stLevelBBStart(MOS_COMMAND_BUFFER &cmdBuffer, MOS_C
     {
         return;
     }
-    PMOS_MUTEX mutex = pOcaInterface->GetMutex();
-    if (mutex == nullptr)
-    {
-        OnOcaError(&mosContext, MOS_STATUS_NULL_POINTER, __FUNCTION__, __LINE__);
-        return;
-    }
+
     ocaBufHandle = GetOcaBufferHandle(cmdBuffer, (MOS_CONTEXT_HANDLE)&mosContext);
     if (ocaBufHandle != MOS_OCA_INVALID_BUFFER_HANDLE)
     {
@@ -646,18 +706,15 @@ void HalOcaInterfaceNext::On1stLevelBBStart(MOS_COMMAND_BUFFER &cmdBuffer, MOS_C
     }
     else
     {
-        MosOcaAutoLock autoLock(mutex);
         ocaBufHandle = pOcaInterface->LockOcaBufAvailable(&mosContext, gpuContextHandle);
+
         if (MOS_OCA_INVALID_BUFFER_HANDLE == ocaBufHandle)
         {
             OnOcaError(&mosContext, MOS_STATUS_INVALID_HANDLE, __FUNCTION__, __LINE__);
             return;
         }
-        auto success = s_hOcaMap.insert(std::make_pair(cmdBuffer.pCmdBase, ocaBufHandle));
-        if (!success.second)
+        if (MOS_FAILED(pOcaInterface->InsertOcaBufHandleMap(cmdBuffer.pCmdBase, ocaBufHandle)))
         {
-            // Should never come to here.
-            MOS_OS_ASSERTMESSAGE("ocaBufHandle has already been assigned to current cmdBuffer!");
             OnOcaError(&mosContext, MOS_STATUS_INVALID_HANDLE, __FUNCTION__, __LINE__);
             return;
         }
